package com.oqpo.api.service.loanmng;


import com.oqpo.api.entity.settmng.StlMgntBaseInfoEntity;
import com.oqpo.api.entity.settmng.StlMgntDtlPtclEntity;
import com.oqpo.api.mapper.loanmng.UnpaidMngMapper;
import com.oqpo.api.service.CommonService;
import com.oqpo.api.web.dto.request.GridRequest;
import com.oqpo.api.web.dto.response.GridResponse;
import com.oqpo.api.web.dto.response.loanmng.UnpaidMngInfoResponse;
import com.oqpo.api.web.dto.response.loanmng.UnpaidMngListResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

@Service
@Slf4j
public class UnpaidMngService extends CommonService {

    @Autowired
    private UnpaidMngMapper unpaidMngMapper;

    /*
      미납금관리 그리드 리스트 조회
     */
    public GridResponse selectUnpaidMngGridList(String sBrandId, String sStoreId, String fromDt, String toDt, GridRequest gridRequest) throws Exception {
        int gridPage = gridRequest.getGridPage();
        int gridSize = gridRequest.getGridSize();

        int gridRecords = unpaidMngMapper.selectUnpaidMngGridCnt(sBrandId, sStoreId, fromDt, toDt);
        int gridTotal = fnCalculateGridTotal(gridSize, gridRecords);
        List<StlMgntBaseInfoEntity> entities = unpaidMngMapper.selectUnpaidMngGridList(sBrandId, sStoreId, fromDt, toDt, gridRequest);
        List<Object> gridRows = entities.stream()
                .map(m -> UnpaidMngListResponse.builder()
                        .viewCd("R")
                        .sttlMgntUnqNo(m.getSttlMgntUnqNo())
                        .sttlReqDt(m.getSttlReqDt())
                        .brandId(m.getBrandId())
                        .brandNm(m.getBrandNm())
                        .storeId(m.getStoreId())
                        .storeNm(m.getStoreNm())
                        .sttlStCd(m.getSttlStCd())
                        .sttlStNm(m.getSttlStNm())
                        .sttlReqAmt(m.getSttlReqAmt())
                        .sttlDt(m.getSttlDt())
                        .sttlAmt(m.getSttlAmt())
                        .build())
                .collect(Collectors.toList());
        return GridResponse.toDTO(gridPage, gridTotal, gridRecords, gridRows);
    }

    /* 미납금관리 정보 조회 */
    public UnpaidMngInfoResponse selectUnpaidMngInfo(String sttlMgntUnqNo) throws Exception {
        StlMgntBaseInfoEntity entity = unpaidMngMapper.selectStlMgntBaseInfo(sttlMgntUnqNo);
        List<StlMgntDtlPtclEntity> dtlPtclEntities = unpaidMngMapper.selectStlMgntDtlPtclList(sttlMgntUnqNo);
        return UnpaidMngInfoResponse.toDTO(entity, dtlPtclEntities);
    }

}
