package com.oqpo.api.web.dto.response.loanmng;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.oqpo.api.entity.settmng.StlMgntBaseInfoEntity;
import com.oqpo.api.entity.settmng.StlMgntDtlPtclEntity;
import io.swagger.annotations.ApiModelProperty;
import lombok.*;

import java.util.List;
import java.util.stream.Collectors;


@Getter
@Setter
@Builder
@AllArgsConstructor(access = AccessLevel.PROTECTED)
@JsonInclude(JsonInclude.Include.ALWAYS)
public class UnpaidMngInfoResponse {

    @ApiModelProperty(value = "정산관리고유번호")
    private String sttlMgntUnqNo;
    @ApiModelProperty(value = "정산요청일자")
    private String sttlReqDt;
    @ApiModelProperty(value = "브랜드아이디")
    private String brandId;
    @ApiModelProperty(value = "브랜드명")
    private String brandNm;
    @ApiModelProperty(value = "매장아이디")
    private String storeId;
    @ApiModelProperty(value = "매장명")
    private String storeNm;
    @ApiModelProperty(value = "정산상태코드")
    private String sttlStCd;
    @ApiModelProperty(value = "정산상태명")
    private String sttlStNm;
    @ApiModelProperty(value = "정산요청금액")
    private long sttlReqAmt;
    @ApiModelProperty(value = "정산일자")
    private String sttlDt;
    @ApiModelProperty(value = "정산금액")
    private long sttlAmt;
    @ApiModelProperty(value = "정산등록담당자명")
    private String sttlRegMgrNm;
    @ApiModelProperty(value = "정산등록담당자아이디")
    private String sttlRegMgrId;
    @ApiModelProperty(value = "시스템등록일시")
    private String sysRegDttm;
    @ApiModelProperty(value = "시스템등록아이디")
    private String sysRegId;
    @ApiModelProperty(value = "시스템등록자")
    private String sysRegNm;
    @ApiModelProperty(value = "시스템변경일시")
    private String sysChgDttm;
    @ApiModelProperty(value = "시스템변경아이디")
    private String sysChgId;

    @ApiModelProperty(value = "계좌잔액")
    private long acctBal;

    @ApiModelProperty(value = "정산대상내역")
    private List<StlDtlPtclInfo> stlDtlPtclList;

    public static UnpaidMngInfoResponse toDTO(StlMgntBaseInfoEntity entity, List<StlMgntDtlPtclEntity> dtlPtclEntities) {
        if (entity == null) return null;
        return UnpaidMngInfoResponse.builder()
                .sttlMgntUnqNo(entity.getSttlMgntUnqNo())
                .sttlReqDt(entity.getSttlReqDt())
                .brandId(entity.getBrandId())
                .brandNm(entity.getBrandNm())
                .storeId(entity.getStoreId())
                .storeNm(entity.getStoreNm())
                .sttlStCd(entity.getSttlStCd())
                .sttlStNm(entity.getSttlStNm())
                .sttlReqAmt(entity.getSttlReqAmt())
                .sttlDt(entity.getSttlDt())
                .sttlAmt(entity.getSttlAmt())
                .sttlRegMgrNm(entity.getSttlRegMgrNm())
                .sttlRegMgrId(entity.getSttlRegMgrId())
                .sysRegDttm(entity.getSysRegDttm())
                .sysRegId(entity.getSysRegId())
                .sysChgDttm(entity.getSysChgDttm())
                .sysChgId(entity.getSysChgId())
                .stlDtlPtclList(dtlPtclEntities.stream()
                        .map(m -> StlDtlPtclInfo.builder()
                                .sttlMgntUnqNo(m.getSttlMgntUnqNo())
                                .sttlMgntDtlNo(m.getSttlMgntDtlNo())
                                .brandId(m.getBrandId())
                                .brandNm(m.getBrandNm())
                                .whsMgntUnqNo(m.getWhsMgntUnqNo())
                                .rtnMgntUnqNo(m.getRtnMgntUnqNo())
                                .storeId(m.getStoreId())
                                .storeNm(m.getStoreNm())
                                .itemId(m.getItemId())
                                .itemNm(m.getItemNm())
                                .unit(m.getUnit())
                                .unitAmt(m.getUnitAmt())
                                .podrQty(m.getPodrQty())
                                .dlvQty(m.getDlvQty())
                                .whsQty(m.getWhsQty())
                                .colQty(m.getColQty())
                                .whsColQty(m.getWhsColQty())        /* 입고/수거수량 */
                                .dlvCmpltDt(m.getDlvCmpltDt())
                                .colDt(m.getColDt())
                                .whsColDt(m.getWhsColDt())          /* 입고/수거일자 */
                                .whsAmt(m.getWhsAmt())
                                .colAmt(m.getColAmt())
                                .whsColAmt(m.getWhsColAmt())        /* 입고/수거금액 */
                                .sttlDvsn(m.getSttlDvsn())
                                .sttlDvsnNm(m.getSttlDvsnNm())
                                .pchPodrUnqNo(m.getPchPodrUnqNo())
                                .pchPodrDtlNo(m.getPchPodrDtlNo())
                                .pchReqUnqNo(m.getPchReqUnqNo())
                                .pchReqDtlNo(m.getPchReqDtlNo())
                                .rtnPodrUnqNo(m.getRtnPodrUnqNo())
                                .rtnPodrDtlNo(m.getRtnPodrDtlNo())
                                .rtnReqUnqNo(m.getRtnReqUnqNo())
                                .rtnReqDtlNo(m.getRtnReqDtlNo())
                                .sysRegDttm(m.getSysRegDttm())
                                .sysRegId(m.getSysRegId())
                                .sysChgDttm(m.getSysChgDttm())
                                .sysChgId(m.getSysChgId())
                                .build())
                        .collect(Collectors.toList()))
                .build();
    }

    @Getter
    @Builder
    @AllArgsConstructor(access = AccessLevel.PROTECTED)
    static class StlDtlPtclInfo {

        @ApiModelProperty(value = "정산관리고유번호")
        private String sttlMgntUnqNo;
        @ApiModelProperty(value = "정산관리상세번호")
        private String sttlMgntDtlNo;
        @ApiModelProperty(value = "브랜드아이디")
        private String brandId;
        @ApiModelProperty(value = "브랜드명")
        private String brandNm;
        @ApiModelProperty(value = "입고관리고유번호")
        private String whsMgntUnqNo;
        @ApiModelProperty(value = "반품관리고유번호")
        private String rtnMgntUnqNo;
        @ApiModelProperty(value = "매장아이디")
        private String storeId;
        @ApiModelProperty(value = "매장명")
        private String storeNm;
        @ApiModelProperty(value = "품목아이디")
        private String itemId;
        @ApiModelProperty(value = "품목명")
        private String itemNm;
        @ApiModelProperty(value = "단위")
        private String unit;
        @ApiModelProperty(value = "단가금액")
        private long unitAmt;
        @ApiModelProperty(value = "발주수량")
        private int podrQty;
        @ApiModelProperty(value = "납품수량")
        private int dlvQty;

        @ApiModelProperty(value = "입고수량")
        private int whsQty;
        @ApiModelProperty(value = "수거수량")
        private int colQty;
        @ApiModelProperty(value = "입고/수거수량")
        private int whsColQty;

        @ApiModelProperty(value = "납품완료일자")
        private String dlvCmpltDt;
        @ApiModelProperty(value = "수거일자")
        private String colDt;
        @ApiModelProperty(value = "입고/수거일자")
        private String whsColDt;

        @ApiModelProperty(value = "입고금액")
        private long whsAmt;
        @ApiModelProperty(value = "수거금액")
        private long colAmt;
        @ApiModelProperty(value = "입고/수거금액")
        private long whsColAmt;

        @ApiModelProperty(value = "정산요청금액")
        private long sttlReqAmt;

        @ApiModelProperty(value = "정산구분")
        private String sttlDvsn;
        @ApiModelProperty(value = "정산구분명")
        private String sttlDvsnNm;
        @ApiModelProperty(value = "구매발주고유번호")
        private String pchPodrUnqNo;
        @ApiModelProperty(value = "구매발주상세번호")
        private String pchPodrDtlNo;
        @ApiModelProperty(value = "구매요청고유번호")
        private String pchReqUnqNo;
        @ApiModelProperty(value = "구매요청상세번호")
        private String pchReqDtlNo;
        @ApiModelProperty(value = "반품발주고유번호")
        private String rtnPodrUnqNo;
        @ApiModelProperty(value = "반품발주상세번호")
        private String rtnPodrDtlNo;
        @ApiModelProperty(value = "반품요청고유번호")
        private String rtnReqUnqNo;
        @ApiModelProperty(value = "반품요청상세번호")
        private String rtnReqDtlNo;
        @ApiModelProperty(value = "시스템등록일시")
        private String sysRegDttm;
        @ApiModelProperty(value = "시스템등록아이디")
        private String sysRegId;
        @ApiModelProperty(value = "시스템변경일시")
        private String sysChgDttm;
        @ApiModelProperty(value = "시스템변경아이디")
        private String sysChgId;

        @ApiModelProperty(value = "발주고유번호")
        private String podrUnqNo;
        @ApiModelProperty(value = "발주상세번호")
        private String podrDtlNo;

    }

}
